@@ -6,7 +6,7 @@ import httplib
 import atom
 import threading
 import re
-from os import unlink
+import os
 
 class DownloadThread (threading.Thread):
 	def __init__ (self, youtube, url, treeview_name):
@@ -16,7 +16,11 @@ class DownloadThread (threading.Thread):
 		threading.Thread.__init__ (self)
 	def run (self):
 		self.youtube.entry_lock.acquire (True)
-		self.youtube.entry[self.treeview_name] = self.youtube.service.Get (self.url).entry
+		try:
+			self.youtube.entry[self.treeview_name] = self.youtube.service.Get (self.url).entry
+		except gdata.service.RequestError:
+			"""Probably a 503 service unavailable. Unfortunately we can't give an error message, as we're not in the GUI thread"""
+			"""Just let the lock go and return"""
 		self.youtube.entry_lock.release ()
 
 class YouTube (totem.Plugin):
@@ -41,8 +45,9 @@ class YouTube (totem.Plugin):
 
 		self.vadjust = {}
 		self.liststore = {}
+		self.treeview = {}
 	def activate (self, totem_object):
-		"""Check for the availability of the flvdemux and soup GStreamer plugins"""
+		"""Check for the availability of the flvdemux and souphttpsrc GStreamer plugins"""
 		bvw_name = totem_object.get_video_widget_backend_name ()
 
 		if bvw_name.find ("GStreamer") != -1:
@@ -96,6 +101,23 @@ class YouTube (totem.Plugin):
 		treeview.connect_after ("starting-video", self.on_starting_video)
 		treeview.insert_column_with_attributes (0, _("Videos"), renderer, thumbnail=0, title=1)
 
+		"""Add the extra popup menu options. This is done here rather than in the UI file, because it's done for multiple treeviews;
+		if it were done in the UI file, the same action group would be used multiple times, which GTK+ doesn't like."""
+		ui_manager = treeview.get_ui_manager ()
+		action_group = gtk.ActionGroup ("youtube-action-group")
+		action = gtk.Action ("open-in-web-browser", _("_Open in Web Browser"), _("Open the video in your web browser"), "gtk-jump-to")
+		action_group.add_action_with_accel (action, None)
+
+		ui_manager.insert_action_group (action_group, 1)
+		ui_manager.add_ui (ui_manager.new_merge_id (),
+				   "/ui/totem-video-list-popup/",
+				   "open-in-web-browser",
+				   "open-in-web-browser",
+				   gtk.UI_MANAGER_MENUITEM,
+				   False)
+		menu_item = ui_manager.get_action ("/ui/totem-video-list-popup/open-in-web-browser")
+		menu_item.connect ("activate", self.on_open_in_web_browser_activated)
+
 		self.vadjust[treeview_name] = treeview.get_vadjustment ()
 		self.vadjust[treeview_name].connect ("value-changed", self.on_value_changed)
 		vscroll = self.builder.get_object ("yt_scrolled_window_" + treeview_name).get_vscrollbar ()
@@ -103,6 +125,7 @@ class YouTube (totem.Plugin):
 		vscroll.connect ("button-release-event", self.on_button_release_event)
 
 		self.liststore[treeview_name] = self.builder.get_object ("yt_liststore_" + treeview_name)
+		self.treeview[treeview_name] = treeview
 		treeview.set_model (self.liststore[treeview_name])
 	def on_notebook_page_changed (self, notebook, notebook_page, page_num):
 		self.current_treeview_name = self.notebook_pages[page_num]
@@ -115,7 +138,21 @@ class YouTube (totem.Plugin):
 		self.youtube_id = youtube_id
 		self.start_index["related"] = 1
 		self.results["related"] = 0
-		self.get_results ("/feeds/videos/" + urllib.quote (youtube_id) + "/related?max-results=" + str (self.max_results), "related")
+		self.get_results ("/feeds/api/videos/" + urllib.quote (youtube_id) + "/related?max-results=" + str (self.max_results), "related")
+	def check_url_for_redirects (self, url_path):
+		try:
+			conn = httplib.HTTPConnection ("www.youtube.com")
+			conn.request ("GET", url_path)
+			response = conn.getresponse ()
+			conn.close ()
+		except:
+			print "Could not resolve stream MRL for YouTube video \"" + url_path + "\"."
+			return False
+
+		if response.status >= 300 and response.status < 400:
+			return response.getheader("location")
+		else:
+			return False
 	def on_starting_video (self, treeview, path, user_data):
 		"""Display an error if the required GStreamer plugins aren't installed"""
 		if self.gstreamer_plugins_present == False:
@@ -131,24 +168,30 @@ class YouTube (totem.Plugin):
 		youtube_id = model.get_value (iter, 3)
 
 		"""Get the video stream MRL"""
-		try:
-			conn = httplib.HTTPConnection ("www.youtube.com")
-			conn.request ("GET", "/v/" + urllib.quote (youtube_id))
-			response = conn.getresponse ()
-		except:
-			print "Could not resolve stream MRL for YouTube video \"" + youtube_id + "\"."
-			return False
+		location = self.check_url_for_redirects ("/v/" + urllib.quote (youtube_id))
 
-		if response.status == 303:
-			location = response.getheader("location")
+		if location != False:
 			mrl = "http://www.youtube.com/get_video?video_id=" + urllib.quote (youtube_id) + "&t=" + urllib.quote (re.match (".*[?&]t=([^&]+)", location).groups ()[0])
+			"""location_check = self.check_url_for_redirects (mrl)
+			if location_check != False:
+				mrl = location_check
+			else:
+				mrl = "http://www.youtube.com" + mrl"""
 		else:
-			mrl = "http://www.youtube.com/v/" + urllib.quote (youtube_id)
-		conn.close ()
+			"""Leave it as taken from the GData feed"""
+			mrl = False
 
-		model.set_value (iter, 2, mrl)
+		if mrl != False:
+			model.set_value (iter, 2, mrl)
 
 		return True
+	def on_open_in_web_browser_activated (self, action):
+		model, rows = self.treeview[self.current_treeview_name].get_selection ().get_selected_rows ()
+		iter = model.get_iter (rows[0])
+		youtube_id = model.get_value (iter, 3)
+
+		"""Open the video in the browser"""
+		os.spawnlp (os.P_NOWAIT, "xdg-open", "xdg-open", "http://www.youtube.com/watch?v=" + urllib.quote (youtube_id))
 	def on_button_press_event (self, widget, event):
 		self.button_down = True
 	def on_button_release_event (self, widget, event):
@@ -159,11 +202,11 @@ class YouTube (totem.Plugin):
 		if not self.button_down and (adjustment.get_value () + adjustment.page_size) / adjustment.upper > 0.8 and self.results[self.current_treeview_name] >= self.max_results:
 			self.results[self.current_treeview_name] = 0
 			if self.current_treeview_name == "search":
-				self.get_results ("/feeds/videos?vq=" + urllib.quote_plus (self.search_terms) + "&max-results=" + str (self.max_results) + "&orderby=relevance&start-index=" + str (self.start_index["search"]), "search", False)
+				self.get_results ("/feeds/api/videos?vq=" + urllib.quote_plus (self.search_terms) + "&max-results=" + str (self.max_results) + "&orderby=relevance&start-index=" + str (self.start_index["search"]), "search", False)
 				if self.debug:
 					print "Getting more results for search \"" + self.search_terms + "\" from offset " + str (self.start_index["search"])
 			elif self.current_treeview_name == "related":
-				self.get_results ("/feeds/videos/" + urllib.quote_plus (self.youtube_id) + "/related?max-results=" + str (self.max_results) + "&start-index=" + str (self.start_index["related"]), "related", False)
+				self.get_results ("/feeds/api/videos/" + urllib.quote_plus (self.youtube_id) + "/related?max-results=" + str (self.max_results) + "&start-index=" + str (self.start_index["related"]), "related", False)
 				if self.debug:
 					print "Getting more related videos for video \"" + self.youtube_id + "\" from offset " + str (self.start_index["related"])
 	def convert_url_to_id (self, url):
@@ -190,31 +233,35 @@ class YouTube (totem.Plugin):
 		self.results[treeview_name] += 1
 		self.start_index[treeview_name] += 1
 		youtube_id = self.convert_url_to_id (entry.id.text)
-		mrl = "http://www.youtube.com/v/" + urllib.quote (youtube_id)
 
 		self.entry_lock.release ()
 
-		"""Find the thumbnail tag"""
+		"""Find the content tag"""
 		for _element in entry.extension_elements:
-			if _element.tag == "group":
-				break
+			if _element.tag =="group":
+				break;
+
+		content_elements = _element.FindChildren ("content")
+		if len (content_elements) == 0:
+			return True;
+		mrl = content_elements[0].attributes['url']
 
 		"""Download the thumbnail and store it in a temporary location so we can get a pixbuf from it"""
 		thumbnail_url = _element.FindChildren ("thumbnail")[0].attributes['url']
 		try:
 			filename, headers = urllib.urlretrieve (thumbnail_url)
 		except IOError:
-			print "Could not load thumbnail " + thumbnail_url + " for video."
+			print "Could not retrieve thumbnail " + thumbnail_url + " for video."
 			return True
 
 		try:
 			pixbuf = gtk.gdk.pixbuf_new_from_file (filename)
 		except gobject.GError:
-			print "Could not load thumbnail " + filename + " for video. It has been left in place for investigation."
+			print "Could not open thumbnail " + filename + " for video. It has been left in place for investigation."
 			return True
 
 		"""Don't leak the temporary file"""
-		unlink (filename)
+		os.unlink (filename)
 
 		self.liststore[treeview_name].append ([pixbuf, entry.title.text, mrl, youtube_id])
 
@@ -231,7 +278,7 @@ class YouTube (totem.Plugin):
 		self.search_terms = search_terms
 		self.start_index["search"] = 1
 		self.results["search"] = 0
-		self.get_results ("/feeds/videos?vq=" + urllib.quote_plus (search_terms) + "&orderby=relevance&max-results=" + str (self.max_results), "search")
+		self.get_results ("/feeds/api/videos?vq=" + urllib.quote_plus (search_terms) + "&orderby=relevance&max-results=" + str (self.max_results), "search")
 	def on_search_entry_activated (self, entry):
 		self.search_button.clicked ()
 	def get_results (self, url, treeview_name, clear = True):
