@@ -20,7 +20,7 @@
  * permission are above and beyond the permissions granted by the GPL license
  * Totem is covered by.
  *
- * Monday 7th February 2005: Christian Schaller: Add excemption clause.
+ * Monday 7th February 2005: Christian Schaller: Add exception clause.
  * See license_change file for details.
  *
  */
@@ -29,7 +29,6 @@
 #include "config.h"
 #endif
 
-#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
 #ifndef HAVE_GTK_ONLY
@@ -41,12 +40,13 @@
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <libgnomevfs/gnome-vfs-init.h>
+#include <glib/gi18n.h>
 
+#include "totem-resources.h"
 #include "totem-mime-types.h"
 
 static gboolean show_mimetype = FALSE;
+static gboolean g_fatal_warnings = FALSE;
 static char **filenames = NULL;
 
 static void
@@ -139,6 +139,7 @@ on_got_metadata_event (BaconVideoWidget *bvw, gpointer data)
 
 static const GOptionEntry entries[] = {
 	{"mimetype", 'm', 0, G_OPTION_ARG_NONE, &show_mimetype, "List the supported mime-types", NULL},
+	{"g-fatal-warnings", 0, 0, G_OPTION_ARG_NONE, &g_fatal_warnings, "Make all warnings fatal", NULL},
 	{G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &filenames, "Movies to index", NULL},
 	{NULL}
 };
@@ -168,13 +169,20 @@ int main (int argc, char **argv)
 	gnome_authentication_manager_init ();
 #endif
 
-	gnome_vfs_init ();
 	if (g_option_context_parse (context, &argc, &argv, &error) == FALSE) {
 		g_print ("couldn't parse command-line options: %s\n", error->message);
 		g_error_free (error);
 		return 1;
 	}
 
+	if (g_fatal_warnings) {
+		GLogLevelFlags fatal_mask;
+
+		fatal_mask = g_log_set_always_fatal (G_LOG_FATAL_MASK);
+		fatal_mask |= G_LOG_LEVEL_WARNING | G_LOG_LEVEL_CRITICAL;
+		g_log_set_always_fatal (fatal_mask);
+	}
+
 	if (show_mimetype == TRUE) {
 		print_mimetypes ();
 		return 0;
@@ -195,6 +203,7 @@ int main (int argc, char **argv)
 			NULL);
 
 	path = filenames[0];
+	totem_resources_monitor_start (path, 0);
 	if (bacon_video_widget_open (bvw, path, &error) == FALSE) {
 		g_print ("Can't open %s: %s\n", path, error->message);
 		return 1;
@@ -203,6 +212,7 @@ int main (int argc, char **argv)
 		g_print ("Can't play %s: %s\n", path, error->message);
 		return 1;
 	}
+	totem_resources_monitor_stop ();
 
 	gtk_main ();
 
