@@ -39,7 +39,6 @@
 #ifndef HAVE_GTK_ONLY
 #include <libgnomeui/gnome-authentication-manager.h>
 #endif
-#include <libgnomevfs/gnome-vfs-init.h>
 #include "bacon-video-widget.h"
 #include "totem-resources.h"
 
@@ -470,8 +469,6 @@ int main (int argc, char *argv[])
 	}
 #endif /* THUMB_DEBUG */
 
-	gnome_vfs_init ();
-
 #ifndef HAVE_GTK_ONLY
 	gnome_authentication_manager_init ();
 #endif
